@@ -2,7 +2,8 @@
 Action to build a Go project using standard Go tooling
 """
 
-from aws_lambda_builders.actions import BaseAction, Purpose, ActionFailedError
+from aws_lambda_builders.actions import ActionFailedError, BaseAction, Purpose
+
 from .builder import BuilderError
 
 
