@@ -4,8 +4,9 @@ Action to resolve NodeJS dependencies using NPM
 
 import logging
 
-from aws_lambda_builders.actions import BaseAction, Purpose, ActionFailedError
+from aws_lambda_builders.actions import ActionFailedError, BaseAction, Purpose
 from aws_lambda_builders.utils import extract_tarfile
+
 from .npm import NpmExecutionError
 
 LOG = logging.getLogger(__name__)
@@ -81,11 +82,10 @@ class NodejsNpmInstallAction(BaseAction):
     DESCRIPTION = "Installing dependencies from NPM"
     PURPOSE = Purpose.RESOLVE_DEPENDENCIES
 
-    def __init__(self, artifacts_dir, subprocess_npm):
+    def __init__(self, install_dir, subprocess_npm):
         """
-        :type artifacts_dir: str
-        :param artifacts_dir: an existing (writable) directory with project source files.
-            Dependencies will be installed in this directory.
+        :type install_dir: str
+        :param install_dir: Dependencies will be installed in this directory.
 
         :type subprocess_npm: aws_lambda_builders.workflows.nodejs_npm.npm.SubprocessNpm
         :param subprocess_npm: An instance of the NPM process wrapper
@@ -95,7 +95,7 @@ class NodejsNpmInstallAction(BaseAction):
         """
 
         super(NodejsNpmInstallAction, self).__init__()
-        self.artifacts_dir = artifacts_dir
+        self.install_dir = install_dir
         self.subprocess_npm = subprocess_npm
 
     def execute(self):
@@ -105,10 +105,10 @@ class NodejsNpmInstallAction(BaseAction):
         :raises lambda_builders.actions.ActionFailedError: when NPM execution fails
         """
         try:
-            LOG.debug("NODEJS installing in: %s", self.artifacts_dir)
+            LOG.debug("NODEJS installing in: %s", self.install_dir)
 
             self.subprocess_npm.run(
-                ["install", "-q", "--no-audit", "--no-save", "--unsafe-perm", "--production"], cwd=self.artifacts_dir
+                ["install", "-q", "--no-audit", "--no-save", "--unsafe-perm", "--production"], cwd=self.install_dir
             )
 
         except NpmExecutionError as ex:
@@ -128,18 +128,17 @@ class NodejsNpmCIAction(BaseAction):
     DESCRIPTION = "Installing dependencies from NPM using the CI method"
     PURPOSE = Purpose.RESOLVE_DEPENDENCIES
 
-    def __init__(self, artifacts_dir, subprocess_npm):
+    def __init__(self, install_dir, subprocess_npm):
         """
-        :type artifacts_dir: str
-        :param artifacts_dir: an existing (writable) directory with project source files.
-            Dependencies will be installed in this directory.
+        :type install_dir: str
+        :param install_dir: Dependencies will be installed in this directory.
 
         :type subprocess_npm: aws_lambda_builders.workflows.nodejs_npm.npm.SubprocessNpm
         :param subprocess_npm: An instance of the NPM process wrapper
         """
 
         super(NodejsNpmCIAction, self).__init__()
-        self.artifacts_dir = artifacts_dir
+        self.install_dir = install_dir
         self.subprocess_npm = subprocess_npm
 
     def execute(self):
@@ -150,9 +149,9 @@ class NodejsNpmCIAction(BaseAction):
         """
 
         try:
-            LOG.debug("NODEJS installing ci in: %s", self.artifacts_dir)
+            LOG.debug("NODEJS installing ci in: %s", self.install_dir)
 
-            self.subprocess_npm.run(["ci"], cwd=self.artifacts_dir)
+            self.subprocess_npm.run(["ci"], cwd=self.install_dir)
 
         except NpmExecutionError as ex:
             raise ActionFailedError(str(ex))
@@ -165,7 +164,7 @@ class NodejsNpmrcAndLockfileCopyAction(BaseAction):
     """
 
     NAME = "CopyNpmrcAndLockfile"
-    DESCRIPTION = "Copying configuration from .npmrc and dependencies from lockfile"
+    DESCRIPTION = "Copying configuration from .npmrc and dependencies from lockfile/shrinkwrap"
     PURPOSE = Purpose.COPY_SOURCE
 
     def __init__(self, artifacts_dir, source_dir, osutils):
@@ -194,7 +193,7 @@ class NodejsNpmrcAndLockfileCopyAction(BaseAction):
         """
 
         try:
-            for filename in [".npmrc", "package-lock.json"]:
+            for filename in [".npmrc", "package-lock.json", "npm-shrinkwrap.json"]:
                 file_path = self.osutils.joinpath(self.source_dir, filename)
                 if self.osutils.file_exists(file_path):
                     LOG.debug("%s copying in: %s", filename, self.artifacts_dir)
